pub fn finalize()Expand description
Deinitializes SAPI for the current thread. This function must be called for every thread that
called initialize(), the same number of times.
pub fn finalize()Deinitializes SAPI for the current thread. This function must be called for every thread that
called initialize(), the same number of times.