AsyncSynthesizer

Struct AsyncSynthesizer 

pub struct AsyncSynthesizer { /* private fields */ }
A speech synthesizer that returns a future for every speech it renders.

Implementations

Source

impl AsyncSynthesizer

pub fn new() -> Result<Self>

Creates a new synthesizer, configured to output its speech to the default audio device.

pub async fn speak<'s, S: Into<Speech<'s>>>(&self, speech: S) -> Result<()>

Completes when the synthesizer finished rendering the given speech.

pub fn speak_and_forget<'s, S: Into<Speech<'s>>>(&self, speech: S) -> Result<()>

Queues up the rendering of the given speech and forgets about it.

Note that this function can be used from both async and synchronous code. The speech will be rendered, but there is no way to await its completion.

Methods from Deref<Target = Synthesizer>

pub fn set_output( &self, output: SpeechOutput, allow_fmt_changes: bool, ) -> Result<()>

Configures the synthesizer to render its speech to the given output destination.

pub fn rate(&self) -> Result<Rate>

Returns the default rate of speech for this synthesizer.

pub fn voice(&self) -> Result<Voice>

Returns the default voice this synthesizer will use to render speech.

pub fn volume(&self) -> Result<Volume>

Returns the default speech volume for this synthesizer.

pub fn set_rate<R: Into<Rate>>(&self, rate: R) -> Result<()>

Sets the default rate of speech for this synthesizer.

pub fn set_voice(&self, voice: &Voice) -> Result<()>

Sets the default voice this synthesizer will use to render speech.

pub fn set_volume<V: Into<Volume>>(&self, volume: V) -> Result<()>

Sets the default speech volume for this synthesizer.