pub struct UnicastContext { /* private fields */ }Expand description
A recognition context paired with a single subscriber that can be awaited for recognition.
Implementations
Sourceimpl UnicastContext
impl UnicastContext
Sourcepub fn new(
recognizer: &Recognizer,
buffer: usize,
) -> Result<(Self, UnicastSubscriber)>
pub fn new( recognizer: &Recognizer, buffer: usize, ) -> Result<(Self, UnicastSubscriber)>
Creates a new recognition context for the given recognizer, configured to buffer up to the given number of recognized phrases. If a new phrase is recognized while the buffer is full, it will be silently dropped.
Methods from Deref<Target = Context>
Sourcepub fn set_enabled(&self, enabled: bool) -> Result<()>
pub fn set_enabled(&self, enabled: bool) -> Result<()>
Enables or disables the recognition of rules from all grammars loaded into this context.
Sourcepub fn grammar_builder(&self) -> GrammarBuilder<'_>
pub fn grammar_builder(&self) -> GrammarBuilder<'_>
Creates a GrammarBuilder that will construct and load a grammar into this context.