SayAs

Enum SayAs 

pub enum SayAs<'s> {
Show 15 variants DateMDY, DateDMY, DateYMD, DateYM, DateMY, DateDM, DateMD, DateYear, Time, NumberCardinal, NumberDigit, NumberFraction, NumberDecimal, PhoneNumber, Custom(&'s str),
}
Provides a hint about how to pronounce the associated content.

Variants



DateMDY

Pronounce a sequence of numbers as a date, e.g. “03/08/2000” as “march eighth two thousand”.



DateDMY

Pronounce a sequence of numbers as a date, e.g. “03/08/2000” as “august third two thousand”.



DateYMD

Pronounce a sequence of numbers as a date, e.g. “2000/08/03” as “march eighth two thousand”.



DateYM

Pronounce a sequence of numbers as a year and month, e.g. “2000/03” as “march two thousand”.



DateMY

Pronounce a sequence of numbers as a month and year, e.g. “03/2000” as “march two thousand”.



DateDM

Pronounce a sequence of numbers as a day and month, e.g. “03/08” as “march eighth”.



DateMD

Pronounce a sequence of numbers as a month and day, e.g. “03/08” as “august third”.



DateYear

Pronounce a number as a year, e.g. “1979” as “nineteen seventy-nine”.



Time

Pronounce a sequence of numbers as a time, e.g. “10:24” as “ten twenty-four”.



NumberCardinal

Pronounce a number as a cardinal number, e.g. “1024” as “one thousand twenty-four”.



NumberDigit

Pronounce a number as a sequence of digits, e.g. “1024” as “one zero two four”.



NumberFraction

Pronounce a number as a fraction, e.g. “3/8” as “three eighths”.



NumberDecimal

Pronounce a number as a fraction, e.g. “10.24” as “ten point two four”.



PhoneNumber

Pronounce a sequence of numbers as a telephone, e.g. “(206) 555-1234” as “two zero six five five five one two three four”.



Custom(&'s str)

A custom pronunciation hint supported by the engine.