pub enum SpeechOutput {
Default,
Stream(AudioStream),
}Expand description
Specifies where the output of speech synthesis should go.
Variants
Default
Output to the default audio device on the system
Stream(AudioStream)
Write to the given stream