pub struct VoiceSelector { /* private fields */ }Expand description
Encapsulates the criteria for selecting a voice.
Implementations
Sourceimpl VoiceSelector
impl VoiceSelector
Sourcepub fn name_eq<S: AsRef<str>>(self, name: S) -> Self
pub fn name_eq<S: AsRef<str>>(self, name: S) -> Self
Returns a selector that requires the voice to have the given name, along with all the previously specified conditions.
Sourcepub fn name_ne<S: AsRef<str>>(self, name: S) -> Self
pub fn name_ne<S: AsRef<str>>(self, name: S) -> Self
Returns a selector that requires the voice to have a name different from the one given here, along with all the previously specified conditions.
Sourcepub fn age_eq(self, age: VoiceAge) -> Self
pub fn age_eq(self, age: VoiceAge) -> Self
Returns a selector that requires the voice to have the given age, along with all the previously specified conditions.
Sourcepub fn age_ne(self, age: VoiceAge) -> Self
pub fn age_ne(self, age: VoiceAge) -> Self
Returns a selector that requires the voice to have an age different from the one given here, along with all the previously specified conditions.
Sourcepub fn gender_eq(self, gender: VoiceGender) -> Self
pub fn gender_eq(self, gender: VoiceGender) -> Self
Returns a selector that requires the voice to have the given gender, along with all the previously specified conditions.
Sourcepub fn gender_ne(self, gender: VoiceGender) -> Self
pub fn gender_ne(self, gender: VoiceGender) -> Self
Returns a selector that requires the voice to have a gender different from the one given here, along with all the previously specified conditions.
Sourcepub fn language_eq<S: AsRef<str>>(self, language: S) -> Self
pub fn language_eq<S: AsRef<str>>(self, language: S) -> Self
Returns a selector that requires the voice to have the given language, along with all the previously specified conditions.
Sourcepub fn language_ne<S: AsRef<str>>(self, language: S) -> Self
pub fn language_ne<S: AsRef<str>>(self, language: S) -> Self
Returns a selector that requires the voice to have a language different from the one given here, along with all the previously specified conditions.