Module audio

Module audio 

Support for streaming audio to and from files and memory buffers.

Structs

AudioFormat
Specifies the format of the audio data in a stream.
AudioStream
An audio stream to read from or write to.
MemoryStream
A data stream backed by a dynamically-sized memory buffer.

Enums

BitRate
How many bits each sample should have.
Channels
Number of audio channels.
SampleRate
Sample rate, in samples per second, at which to play or record.