Support for streaming audio to and from files and memory buffers.
Structs
- Audio
Format - Specifies the format of the audio data in a stream.
- Audio
Stream - An audio stream to read from or write to.
- Memory
Stream - A data stream backed by a dynamically-sized memory buffer.
Enums
- BitRate
- How many bits each sample should have.
- Channels
- Number of audio channels.
- Sample
Rate - Sample rate, in samples per second, at which to play or record.