pub struct AsyncSynthesizer { /* private fields */ }Expand description
A speech synthesizer that returns a future for every speech it renders.
Implementations
Methods from Deref<Target = Synthesizer>
Sourcepub fn set_output(
&self,
output: SpeechOutput,
allow_fmt_changes: bool,
) -> Result<()>
pub fn set_output( &self, output: SpeechOutput, allow_fmt_changes: bool, ) -> Result<()>
Configures the synthesizer to render its speech to the given output destination.
Sourcepub fn voice(&self) -> Result<Voice>
pub fn voice(&self) -> Result<Voice>
Returns the default voice this synthesizer will use to render speech.
Sourcepub fn set_rate<R: Into<Rate>>(&self, rate: R) -> Result<()>
pub fn set_rate<R: Into<Rate>>(&self, rate: R) -> Result<()>
Sets the default rate of speech for this synthesizer.